==> Dist-Zilla-Plugin-PortabilityTests-1.100700.tar.gz: Dist-Zilla-Plugin-PortabilityTests-1.100700/lib/Dist/Zilla/Plugin/PortabilityTests.pm <==
use 5.008;
use strict;
use warnings;

package Dist::Zilla::Plugin::PortabilityTests;
our $VERSION = '1.100700';
# ABSTRACT: release tests for portability
use Moose;
use Test::Portability::Files ();
extends 'Dist::Zilla::Plugin::InlineFiles';

__PACKAGE__->meta->make_immutable;
no Moose;
1;




=pod

=head1 NAME

Dist::Zilla::Plugin::PortabilityTests - release tests for portability

=head1 VERSION

version 1.100700

=head1 SYNOPSIS

In C<dist.ini>:

    [PortabilityTests]

=head1 DESCRIPTION

This is an extension of L<Dist::Zilla::Plugin::InlineFiles>, providing the
following files

  xt/release/portability.t - a standard Test::Portability::Files test

=for test_synopsis 1;
__END__

=head1 INSTALLATION

See perlmodinstall for information and options on installing Perl modules.

=head1 BUGS AND LIMITATIONS

No bugs have been reported.

Please report any bugs or feature requests through the web interface at
L<http://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-PortabilityTests>.

=head1 AVAILABILITY

The latest version of this module is available from the Comprehensive Perl
Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
site near you, or see
L<http://search.cpan.org/dist/Dist-Zilla-Plugin-PortabilityTests/>.

The development version lives at
L<http://github.com/hanekomu/Dist-Zilla-Plugin-PortabilityTests/>.
Instead of sending patches, please fork this project using the standard git
and github infrastructure.

=head1 AUTHOR

  Marcel Gruenauer <marcel@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2010 by Marcel Gruenauer.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut


__DATA__
___[ xt/release/portability.t ]___
#!perl

use Test::More;

eval "use Test::Portability::Files";
plan skip_all => "Test::Portability::Files required for testing portability"
  if $@;
run_tests();

==> Dist-Zilla-Plugin-PortabilityTests-1.101420.tar.gz: Dist-Zilla-Plugin-PortabilityTests-1.101420/lib/Dist/Zilla/Plugin/PortabilityTests.pm <==
use 5.008;
use strict;
use warnings;

package Dist::Zilla::Plugin::PortabilityTests;
BEGIN {
  $Dist::Zilla::Plugin::PortabilityTests::VERSION = '1.101420';
}
# ABSTRACT: Release tests for portability
use Moose;
extends 'Dist::Zilla::Plugin::InlineFiles';

__PACKAGE__->meta->make_immutable;
no Moose;
1;




=pod

=head1 NAME

Dist::Zilla::Plugin::PortabilityTests - Release tests for portability

=head1 VERSION

version 1.101420

=head1 SYNOPSIS

In C<dist.ini>:

    [PortabilityTests]

=head1 DESCRIPTION

This is an extension of L<Dist::Zilla::Plugin::InlineFiles>, providing the
following file:

  xt/release/portability.t - a standard Test::Portability::Files test

=for test_synopsis 1;
__END__

=head1 INSTALLATION

See perlmodinstall for information and options on installing Perl modules.

=head1 BUGS AND LIMITATIONS

No bugs have been reported.

Please report any bugs or feature requests through the web interface at
L<http://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-PortabilityTests>.

=head1 AVAILABILITY

The latest version of this module is available from the Comprehensive Perl
Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
site near you, or see
L<http://search.cpan.org/dist/Dist-Zilla-Plugin-PortabilityTests/>.

The development version lives at
L<http://github.com/hanekomu/Dist-Zilla-Plugin-PortabilityTests/>.
Instead of sending patches, please fork this project using the standard git
and github infrastructure.

=head1 AUTHOR

  Marcel Gruenauer <marcel@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2010 by Marcel Gruenauer.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut


__DATA__
___[ xt/release/portability.t ]___
#!perl

use Test::More;

eval "use Test::Portability::Files";
plan skip_all => "Test::Portability::Files required for testing portability"
  if $@;
run_tests();
